/*
 * Copyright 2020 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef CPPBUF2PY_H
#define CPPBUF2PY_H

#include "fwk.h"
#include <iostream>

// http://bo-peng.blogspot.be/2004/10/how-to-re-direct-cout-to-python_05.html
// https://docs.python.org/2/c-api/sys.html#system-functions

/**
 * @brief redirect a std::stream to python
 */
#ifndef SWIG
class CppBuf2Py : public std::basic_streambuf<char>
{
public:
    typedef std::char_traits<char> traits_type;
    typedef traits_type::int_type int_type;

private:
    std::ostream &stream;
    std::streambuf *oldbuf;
    bool verb;
    bool errstream;

public:
    CppBuf2Py(std::ostream &o1, bool err = false);
    ~CppBuf2Py();

    static void test();

protected:
    virtual std::streamsize xsputn(const char *s, std::streamsize n);
    virtual int_type overflow(int c);
};
#endif // SWIG

/**
 * @brief redirect std::cout/std::cerr to python sys.stdout/sys.stderr
 */

class StdOutErr2Py
{
    CppBuf2Py out;
    CppBuf2Py err;

public:
    StdOutErr2Py();

    static void test();
};

#endif // CPPBUF2PY_H
