/*
 * Copyright 2020 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef WTIMES_H
#define WTIMES_H

#include "fwk.h"
#include "wTime.h"

namespace fwk
{
/**
 * @brief Class containing user, kernel, real (wall clock) CPU time counters
 */

class FWK_API Times
{
#ifdef WIN32
    Int64Time user;
    Int64Time kernel;
    ClockTime real;
#else
    UnixClockTime user;
    UnixClockTime kernel;
    UnixClockTime real;
#endif

public:
    Times read();

    Time const &getUser() const;
    Time const &getKernel() const;
    Time const &getReal() const;

#ifndef SWIG
    // [RB] the following 3 routines looks like a dirty hack from Kim
    // to display Trilinos timers as waves ones
    // @todo remove these calls or replace them by an appropriate (copy) constructor
#ifdef WIN32
    void setUser(Int64Time time)
    {
        user = time;
    }
    void setKernel(Int64Time time) { kernel = time; }
    void setReal(ClockTime time) { real = time; }
#else
    void setUser(UnixClockTime time)
    {
        user = time;
    }
    void setKernel(UnixClockTime time) { kernel = time; }
    void setReal(UnixClockTime time) { real = time; }
#endif
    Times operator+(Times const &obj) const;
    Times operator-(Times const &obj) const;
    friend FWK_API std::ostream &operator<<(std::ostream &out, Times const &obj);
#endif
};

#include "wTimes.inl"
};     // namespace fwk
#endif // WTIMES_H
