/*
 * Copyright 2020 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// tbox global header

#ifndef TBOX_H
#define TBOX_H

#if defined(WIN32)
#ifdef tbox_EXPORTS
#define TBOX_API __declspec(dllexport)
#else
#define TBOX_API __declspec(dllimport)
#endif
#else
#define TBOX_API
#endif

#include "fwk.h"

namespace tbox
{

// Mesh handling
class MshData;
class Node;
class Element;
class Group;
class Groups;
class Tag;

// Element handling
class Cache;

// Point1
class Point1;
class CachePoint1;

// Line2
class SfLine2;
class CacheLine2;
class GaussLine2;
class Line2;

// Tri3
class SfTri3;
class CacheTri3;
class GaussTri3;
class Tri3;

// Quad4
class SfQuad4;
class CacheQuad4;
class GaussQuad4;
class Quad4;

// Tetra4
class SfTetra4;
class CacheTetra4;
class GaussTetra4;
class Tetra4;

// Hex8
class SfHex8;
class CacheHex8;
class GaussHex8;
class Hex8;

// Mesh utilities
class MshImport;
class MshExport;
class GmshImport;
class GmshExport;
class MshDeform;
class MshCrack;
class MshConvert;

// Utilities
class PwLf;
class Fct0;
class Fct1;
class Fct2;
class Results;
class Linesearch;

// Linear solvers
class LinearSolver;
class Pardiso;
class Dss;
class Mumps;
class SparseLu;
class Gmres;

// Testing
class UnitTest;

} // namespace tbox

#endif // TBOX_H
