/*
 * Copyright 2020 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef WGMSHEXPORT_H
#define WGMSHEXPORT_H

#include "tbox.h"
#include "wMshExport.h"
#include <vector>
#include <map>

namespace tbox
{

/**
 * @brief Write mesh in gmsh format
 * @authors Adrien Crovato, Romain Boman
 */
class TBOX_API GmshExport : public MshExport
{
public:
    GmshExport(std::shared_ptr<MshData> _msh);
    virtual ~GmshExport();
    virtual WrtType type() const override { return WrtType::GMSH; }

    virtual void save(std::string const &fname) const override;
#ifndef SWIG
    virtual void save(std::string const &fname, Results const &r) const override;
#endif

    virtual void write(std::ostream &out) const override;
};

} // namespace tbox

#endif // WGMSHEXPORT_H
